/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.clientserverapi.system.logging;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.ow2.petals.clientserverapi.system.logging.exception.LoggingServiceException;

/**
 * This client/server interface define methods for interact with Petals logging system implementation.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface LoggingService {

    /**
     * Get all {@link Level} names supported by Petals.
     * 
     * @return The logging system (JDK logging) {@link Level} names supported by Petals (Default logging system levels
     *         and custom Petals levels).
     * @throws LoggingServiceException
     *             An error occurs getting log levels
     */
    public String[] getLevels() throws LoggingServiceException;

    /**
     * Allow to get all {@link Logger} defined in Petals.
     * 
     * @return The names (index 0) and level (index 1) of all the loggers
     * @throws LoggingServiceException
     *             An error occurs getting loggers
     */
    public String[][] getLoggers() throws LoggingServiceException;

}
